# net-url

PYPI wrapper for lua project net-url. See package information at https://luarocks.org/modules/golgote/net-url.

## Install

```shell
pip install net-url
```

## Installed Command Utils

- manage-net-url

## Usage

```shell
Usage: manage-net-url [OPTIONS] COMMAND [ARGS]...

Options:
  --help  Show this message and exit.

Commands:
  install  Create a lua package and then install it.
  pack     Create a lua package.
```

## About release version

- Version before .postx is the same with the core package version.
- .postx is our release number.

## Releases

### v0.9.1.post2 2020/11/05

- Fix luaproject.get_version problem.

### v0.9.1.post1 2020/10/15

- First release.
